@@ -320,13 +320,17 @@ class Client(Methods):
             ConnectionError: In case you try to disconnect an already disconnected client or in case you try to
                 disconnect a client that needs to be terminated first.
         """
-        if self.end_client:
-            dt_now = datetime.now()
-            months = dt_now + timedelta(minutes=self.end_client)
-            if dt_now == months:
-                if self.is_connected:
-                    await self.stop()
-            else:
+        while not await asyncio.sleep(5):
+            try:
+                if self.end_client:
+                    dt_now = datetime.now()
+                    months = dt_now + timedelta(minutes=self.end_client)
+                    if dt_now == months:
+                        if self.is_connected:
+                            await self.stop()
+                    else:
+                        pass
+            except BaseException:
                 pass
 
     async def listen(self, chat_id, filters=None, timeout=None):
