@@ -16,6 +16,7 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
+import asyncio
 import logging
 
 import pyFipper
@@ -44,7 +45,7 @@ class Initialize:
 
         self.load_plugins()
 
-        await self.endclient()
+        asyncio.create_task(self.endclient())
 
         await self.dispatcher.start()
 
